history_swh: return the history of archive events of a given software repository
Description
Note that unlike the generic history method, SWH history is repo-specific
rather than content-specific. An archive event adds all content from the repo
to the Software Heritage archival snapshot at once. Any individual file can still
be referenced by its content identifier.