Learn R Programming

contentid (version 0.0.15)

retrieve_swh: retrieve content from Software Heritage given a content identifier

Description

retrieve content from Software Heritage given a content identifier

Usage

retrieve_swh(id, host = "https://archive.softwareheritage.org")

Arguments

id

a content identifier

host

the domain name for the Software Heritage API

See Also

retrieve, sources_swh

Examples

Run this code
# NOT RUN {
id <- paste0("hash://sha256/9412325831dab22aeebdd",
             "674b6eb53ba6b7bdd04bb99a4dbb21ddff646287e37")
retrieve_swh(id)

# }

Run the code above in your browser using DataLab